@@ -13,9 +13,13 @@ def retrieve_data_resource(species):
         "funestus",
     ], f"species {species} not recognised, please use 'gambiae_sl' or 'funestus'"
     if species == "gambiae_sl":
-        data_resource = malariagen_data.Ag3(url="gs://vo_agam_release/", pre=True)
+        data_resource = malariagen_data.Ag3(
+            url="gs://vo_agam_release_master_us_central1", pre=True
+        )
     elif species == "funestus":
-        data_resource = malariagen_data.Af1(url="gs://vo_afun_release/", pre=True)
+        data_resource = malariagen_data.Af1(
+            url="gs://vo_afun_release_master_us_central1", pre=True
+        )
     return data_resource
 
 
@@ -39,7 +43,9 @@ def check_my_oligo(
     print("plotting frequencies in ag3 data")
 
     fig = plot_sequence_frequencies(
-        data_resource=malariagen_data.Ag3(url="gs://vo_agam_release/", pre=True),
+        data_resource=malariagen_data.Ag3(
+            url="gs://vo_agam_release_master_us_central1", pre=True
+        ),
         region=region_span,
         sample_sets=sample_sets,
         sample_query=sample_query,
@@ -155,6 +161,23 @@ def _plotly_frequencies(
 #### utility functions ####
 
 
+def round_floats_in_df(df, decimal_places=1):
+    import numpy as np
+
+    def round_if_float(val):
+        if isinstance(val, (int, np.integer)):
+            return val
+        try:
+            float_val = float(val)
+            if float_val.is_integer():
+                return int(float_val)
+            return round(float_val, decimal_places)
+        except (ValueError, TypeError):
+            return val
+
+    return df.applymap(round_if_float)
+
+
 def extract_trailing_digits(string):
     import re
 
@@ -453,8 +476,8 @@ def _plotly_primers(
         showlegend=False,
     )
     if out_dir:
-        fig.write_html(f"{name}_{assay_type}.html")
-        fig.write_image(f"{name}_{assay_type}.pdf")
+        fig.write_html(f"{name}_{assay_type}_snps.html")
+        fig.write_image(f"{name}_{assay_type}_snps.pdf")
     fig.show()
 
 
@@ -551,3 +574,16 @@ def _get_base_freqs(freqs, ref_alt_array):
             base = ref_alt_array[i, i_base]
             freq_df.loc[i, f"{base}_freq"] = freqs[i, i_base]
     return freq_df
+
+
+def load_params_json(param_type):
+    import requests
+
+    url = f"https://raw.githubusercontent.com/sanjaynagi/AnoPrimer/refs/heads/main/AnoPrimer/params/{param_type}.json"
+    # Send a GET request to the URL
+    response = requests.get(url)
+    # Raise an exception for bad status codes
+    response.raise_for_status()
+    # Parse the JSON content
+    data = response.json()
+    return data
